==> libakonadi-24.12.1-1-x86_64.pkg.tar.zst: usr/lib/cmake/KPim6Akonadi/KPim6AkonadiTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KPim6::AkonadiPrivate" for configuration ""
set_property(TARGET KPim6::AkonadiPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim6::AkonadiPrivate PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt6::Network"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPim6AkonadiPrivate.so.6.3.1"
  IMPORTED_SONAME_NOCONFIG "libKPim6AkonadiPrivate.so.6"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiPrivate )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiPrivate "${_IMPORT_PREFIX}/lib/libKPim6AkonadiPrivate.so.6.3.1" )

# Import target "KPim6::AkonadiCore" for configuration ""
set_property(TARGET KPim6::AkonadiCore APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim6::AkonadiCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt6::Network;Qt6::Widgets;KF6::I18n;KF6::IconThemes;KF6::ConfigCore;KPim6::AkonadiPrivate"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPim6AkonadiCore.so.6.3.1"
  IMPORTED_SONAME_NOCONFIG "libKPim6AkonadiCore.so.6"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiCore )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiCore "${_IMPORT_PREFIX}/lib/libKPim6AkonadiCore.so.6.3.1" )

# Import target "KPim6::AkonadiAgentBase" for configuration ""
set_property(TARGET KPim6::AkonadiAgentBase APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim6::AkonadiAgentBase PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KPim6::AkonadiPrivate;KPim6::AkonadiWidgets;KF6::I18n;Qt6::Network;KAccounts6;Qt6::Xml"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPim6AkonadiAgentBase.so.6.3.1"
  IMPORTED_SONAME_NOCONFIG "libKPim6AkonadiAgentBase.so.6"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiAgentBase )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiAgentBase "${_IMPORT_PREFIX}/lib/libKPim6AkonadiAgentBase.so.6.3.1" )

# Import target "KPim6::AkonadiWidgets" for configuration ""
set_property(TARGET KPim6::AkonadiWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim6::AkonadiWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF6::I18n;KF6::IconThemes;KF6::IconWidgets;KF6::XmlGui;Qt6::Sql;KPim6::AkonadiPrivate"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPim6AkonadiWidgets.so.6.3.1"
  IMPORTED_SONAME_NOCONFIG "libKPim6AkonadiWidgets.so.6"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiWidgets )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiWidgets "${_IMPORT_PREFIX}/lib/libKPim6AkonadiWidgets.so.6.3.1" )

# Import target "KPim6::AkonadiXml" for configuration ""
set_property(TARGET KPim6::AkonadiXml APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim6::AkonadiXml PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF6::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPim6AkonadiXml.so.6.3.1"
  IMPORTED_SONAME_NOCONFIG "libKPim6AkonadiXml.so.6"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiXml )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiXml "${_IMPORT_PREFIX}/lib/libKPim6AkonadiXml.so.6.3.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> libakonadi-25.04.2-1-x86_64.pkg.tar.zst: usr/lib/cmake/KPim6Akonadi/KPim6AkonadiTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KPim6::AkonadiPrivate" for configuration ""
set_property(TARGET KPim6::AkonadiPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim6::AkonadiPrivate PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt6::Network"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPim6AkonadiPrivate.so.6.4.2"
  IMPORTED_SONAME_NOCONFIG "libKPim6AkonadiPrivate.so.6"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiPrivate )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiPrivate "${_IMPORT_PREFIX}/lib/libKPim6AkonadiPrivate.so.6.4.2" )

# Import target "KPim6::AkonadiCore" for configuration ""
set_property(TARGET KPim6::AkonadiCore APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim6::AkonadiCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt6::Network;Qt6::Widgets;KF6::I18n;KF6::IconThemes;KF6::ConfigCore;KPim6::AkonadiPrivate"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPim6AkonadiCore.so.6.4.2"
  IMPORTED_SONAME_NOCONFIG "libKPim6AkonadiCore.so.6"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiCore )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiCore "${_IMPORT_PREFIX}/lib/libKPim6AkonadiCore.so.6.4.2" )

# Import target "KPim6::AkonadiAgentBase" for configuration ""
set_property(TARGET KPim6::AkonadiAgentBase APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim6::AkonadiAgentBase PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KPim6::AkonadiPrivate;KPim6::AkonadiWidgets;KF6::I18n;Qt6::Network;KF6::IconThemes;KAccounts6;Qt6::Xml"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPim6AkonadiAgentBase.so.6.4.2"
  IMPORTED_SONAME_NOCONFIG "libKPim6AkonadiAgentBase.so.6"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiAgentBase )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiAgentBase "${_IMPORT_PREFIX}/lib/libKPim6AkonadiAgentBase.so.6.4.2" )

# Import target "KPim6::AkonadiWidgets" for configuration ""
set_property(TARGET KPim6::AkonadiWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim6::AkonadiWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF6::I18n;KF6::IconThemes;KF6::IconWidgets;KF6::XmlGui;Qt6::Sql;KPim6::AkonadiPrivate"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPim6AkonadiWidgets.so.6.4.2"
  IMPORTED_SONAME_NOCONFIG "libKPim6AkonadiWidgets.so.6"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiWidgets )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiWidgets "${_IMPORT_PREFIX}/lib/libKPim6AkonadiWidgets.so.6.4.2" )

# Import target "KPim6::AkonadiXml" for configuration ""
set_property(TARGET KPim6::AkonadiXml APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim6::AkonadiXml PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF6::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPim6AkonadiXml.so.6.4.2"
  IMPORTED_SONAME_NOCONFIG "libKPim6AkonadiXml.so.6"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiXml )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiXml "${_IMPORT_PREFIX}/lib/libKPim6AkonadiXml.so.6.4.2" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
